@@ -28,8 +28,9 @@ import gtk.glade
 import storage
 import editorwindow
 import usersdialog
+import groupsdialog
 import util
-import userdb
+import systemdb
 import protosession
 import debuglog
 import errors
@@ -259,7 +260,7 @@ class ProfilesModel (gtk.ListStore):
 
     def reload (self):
         self.clear ()
-        profiles = userdb.get_database ().get_profiles ()
+        profiles = systemdb.get_user_database ().get_profiles ()
         profiles.sort ()
         for profile in profiles:
             self.set (self.append (),
@@ -354,6 +355,10 @@ class ProfilesDialog:
         self.__fix_button_align (self.users_button)
         self.users_button.connect ("clicked", self.__users_button_clicked)
 
+        self.groups_button = self.xml.get_widget ("groups_button")
+        self.__fix_button_align (self.groups_button)
+        self.groups_button.connect ("clicked", self.__groups_button_clicked)
+
         self.help_button = self.xml.get_widget ("help_button")
         self.help_button.hide ()
 
@@ -433,6 +438,12 @@ class ProfilesDialog:
         if profile_name:
             usersdialog.UsersDialog (profile_name, self.dialog)
 
+    @errors.checked_callback (debuglog.DEBUG_LOG_DOMAIN_USER)
+    def __groups_button_clicked (self, button):
+        profile_name = self.__get_selected_profile ()
+        if profile_name:
+            groupsdialog.GroupsDialog (profile_name, self.dialog)
+
     def __delete_currently_selected (self):
         (model, selected) = self.profiles_list.get_selection ().get_selected ()
         if selected:
@@ -452,7 +463,7 @@ class ProfilesDialog:
             dprint ("Deleting '%s'", profile_name)
             os.remove (_get_profile_path_for_name (profile_name))
 
-            db = userdb.get_database ()
+            db = systemdb.get_user_database ()
             if db.get_default_profile (False) == profile_name:
                 db.set_default_profile (None)
             for user in db.get_users ():
@@ -483,7 +494,7 @@ class ProfilesDialog:
             self.__delete_currently_selected ()
 
     def __make_unique_profile_name (self, profile_name):
-        profiles = userdb.get_database ().get_profiles ()
+        profiles = systemdb.get_user_database ().get_profiles ()
 
         name = profile_name
         idx = 1
@@ -523,4 +534,5 @@ class ProfilesDialog:
         self.edit_button.set_sensitive (profile_name != None)
         self.details_button.set_sensitive (profile_name != None)
         self.users_button.set_sensitive (profile_name != None)
+        self.groups_button.set_sensitive (profile_name != None)
         self.remove_button.set_sensitive (profile_name != None)
