@@ -20,7 +20,7 @@ import os.path
 import pwd
 import gtk
 import gtk.glade
-import userdb
+import systemdb
 import errors
 import debuglog
 
@@ -53,12 +53,12 @@ class UsersModel (gtk.ListStore):
 class UsersDialog:
     def __init__ (self, profile, parent):
         self.profile = profile
-        self.userdb = userdb.get_database ()
+        self.userdb = systemdb.get_user_database ()
 
         apply_to_all = self.userdb.get_default_profile (False) == profile
         
         glade_file = os.path.join (GLADEDIR, "sabayon.glade")
-        self.xml = gtk.glade.XML (glade_file, "users_dialog")
+        self.xml = gtk.glade.XML (glade_file, "users_dialog", PACKAGE)
 
         self.dialog = self.xml.get_widget ("users_dialog")
         self.dialog.set_transient_for (parent)
