@@ -19,12 +19,12 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.28.0"
-LOCALEDIR = "/gnome/usr/share/locale"
-DATADIR    = "/gnome/usr/share"
-SYSCONFDIR = "/gnome/usr/etc"
-LIBEXECDIR = "/gnome/usr/libexec"
-SBINDIR    = "/gnome/usr/sbin"
+VERSION    = "2.29.0"
+LOCALEDIR = "/usr/local/share/locale"
+DATADIR    = "/usr/local/share"
+SYSCONFDIR = "/usr/local/etc"
+LIBEXECDIR = "/usr/local/libexec"
+SBINDIR    = "/usr/local/sbin"
 
 GLADEDIR    = os.path.join (DATADIR, "sabayon", "glade")
 PROFILESDIR = os.path.join (SYSCONFDIR, "desktop-profiles")
@@ -52,7 +52,7 @@ DEFAULT_SHELL = "/bin/bash"
 NOLOGIN_SHELL = "/sbin/nologin"
 SKEL_HOMEDIR  = "/etc/skel"
 
-XEPHYR_ARGV  = [ "/usr/bin/Xephyr", "-terminate", "-audit", "0", "-nolisten", "tcp" ]
+XEPHYR_ARGV  = [ "/usr/bin/Xephyr", "-terminate", "-audit", "0", "-nolisten", "tcp", "-name", "sabayon" ]
 SESSION_ARGV = [ "/etc/gdm/Xsession", "gnome" ]
 USERMOD_ARGV = [ "/usr/sbin/usermod" ]
 
